============================
django-exclusivebooleanfield
============================

Provides an `ExcluveBooleanField` which is a boolean (db) field where only
one row in the table (or optionally, a subset of table based on value of
other fields) is `True` and all the other rows are `False.

See GitHub for usage and docs.